@@ -9,31 +9,40 @@ from . import color as _color
 if _os.name == "posix":
     import paramiko as _paramiko
 
-def encode(content: str, save: bool = False, save_path:str=None):
-    if not save and save_path is not None:
-        raise ValueError("save is off, but still have save path")
-    elif save and save_path is None:
-        raise ValueError("save is on, but save path is None")
-    elif save and save_path is not None:
-        file = open(save_path, "wb")
-        file.write(_base64.b64encode(content.encode("ascii")))
-        file.close()
-    else:
-        return _base64.b64encode(content.encode("ascii"))
-def decode(_bytes: bytes = None, read: bool = False, read_path: str = None):
-    if _bytes is not None and read:
-        raise ValueError("Bytes have been passed in but read mode is still on")
-    elif not read and read_path is not None:
-        raise ValueError("read is off, but still have read path")
-    elif read and read_path is None:
-        raise ValueError("read is on, but read path is None")
-    elif read and read_path is not None:
-        file = open(read_path, "rb")
-        content = _base64.b64decode(file.read()).decode("utf-8")
-        file.close()
-        return content
-    else:
-        return _base64.b64decode(_bytes).decode("utf-8")
+def _merge_string_list(obj: list):
+    new_string = ""
+    for text in obj: new_string += text
+    return new_string
+
+class StringBytes:
+    @staticmethod
+    def encode(content: str, save: bool = False, save_path:str=None):
+        if not save and save_path is not None:
+            raise ValueError("save is off, but still have save path")
+        elif save and save_path is None:
+            raise ValueError("save is on, but save path is None")
+        elif save and save_path is not None:
+            file = open(save_path, "wb")
+            file.write(_base64.b64encode(content.encode("ascii")))
+            file.close()
+        else:
+            return _base64.b64encode(content.encode("ascii"))
+    @staticmethod
+    def decode(_bytes: bytes = None, read: bool = False, read_path: str = None):
+        if _bytes is not None and read:
+            raise ValueError("Bytes have been passed in but read mode is still on")
+        elif not read and read_path is not None:
+            raise ValueError("read is off, but still have read path")
+        elif read and read_path is None:
+            raise ValueError("read is on, but read path is None")
+        elif read and read_path is not None:
+            file = open(read_path, "rb")
+            content = _base64.b64decode(file.read()).decode("utf-8")
+            file.close()
+            return content
+        else:
+            return _base64.b64decode(_bytes).decode("utf-8")
+
 def decimal(obj: float):
     _obj = str(obj)
     returned = []
@@ -44,10 +53,6 @@ def decimal(obj: float):
     rstring = ""
     for char in returned: rstring += char
     return rstring
-def _merge_string_list(obj: list):
-    new_string = ""
-    for text in obj: new_string += text
-    return new_string
 def Round(obj: float, _to: int = 0):
     if not _to: return round(obj)
     if len(str(decimal(obj))) < _to:
@@ -89,8 +94,7 @@ def Range(range_x: int or float, range_y: int or float = None, step: int or floa
         while range_x >= range_y:
             yield range_x
             range_x -= step
-def cindex(a: list, start=0, end=0):
-    return range(start, len(a) + end)
+def frange(a: list, start=0, end=0): return range(start, len(a) + end)
 def calculator(algorithm: str) -> int or float:
     class cache(): 
         def __init__(self, value: object) -> None: self.value = value
@@ -191,24 +195,6 @@ def nameof(var):
     callers_local_vars = _inspect.currentframe().f_back.f_locals.items()
     return [var_name for var_name, var_val in callers_local_vars if var_val is var][0]
 
-def createof(Type, *args, **kwargs):
-    __object__ = Type(*args, **kwargs)
-    for keys, vals in Type.__dict__.items():
-        if type(vals) is list: __object__[keys] = Type.__dict__[keys].copy()
-        if type(vals) is dict: __object__[keys] = Type.__dict__[keys].copy()
-    return __object__
-def Convert(obj, Type):
-    if type(obj) is list:
-        return_list = [].copy()
-        for index in range(len(obj)):
-            return_list[index] = Type(obj[index])
-        return return_list
-    elif type(obj) is dict:
-        return_dict = {}.copy()
-        for key in obj:
-            return_dict[key] = Type(obj[key])
-        return return_dict
-    else: return Type(obj)
 def breakdown(obj):
     return_list = [].copy()
     for index in range(len(obj)):
@@ -219,21 +205,21 @@ def breakdown(obj):
             continue
     return return_list
                 
-def varconvert(var):
+def var(value):
     try:
-        int(var)
-        if "." in var:
-            return float(var)
-        else: return int(var)
+        int(value)
+        if "." in value:
+            return float(value)
+        else: return int(value)
     except ValueError:
-        if var.lower() in ("none", "null"):
+        if value.lower() in ("none", "null"):
             return None
-        if var.lower() == "true":
+        if value.lower() == "true":
             return True
-        if var.lower() == "false":
+        if value.lower() == "false":
             return False
         import ast
-        return ast.literal_eval(var)
+        return ast.literal_eval(value)
 
 class cursor:
     def __init__(self):
@@ -286,6 +272,7 @@ class cursor:
                 return None
             class pos: x = int(groups[1]); y = int(groups[0])
             return pos
+
 class console:
     @staticmethod
     def write(*content, timer: int = 0.02, skip=breakdown(_color.__color__),sep=" " ,end="\n", wait=((",", 0.5), (".", 0.5), ("!", 0.5), ("?", 0.5)), replace=None):
@@ -295,7 +282,7 @@ class console:
                 wd = text[index]
                 if replace:
                     for re in replace:
-                        if wd == re[0]: wd = re[0]
+                        if wd == re[0]: wd = re[1]
                 _system.stdout.write(wd)
                 _system.stdout.flush()
                 if type(skip) is str and wd != skip: _time.sleep(timer)
@@ -357,6 +344,39 @@ class console:
             print(flush = True)
             command = command.split(" ")
             return command
+
+class Bytes:
+    def __init__(self, obj, tag="b"):
+        if type(obj) is list: self.object = obj
+        else: self.object = [obj]
+        self.length = len(obj)
+        self.tag = tag.upper()
+        self.tags = ["BIT", "B", "KB", "MB", "GB", "TB", "PB", "EB", "ZB", "YB", "BB", "NB", "DB",
+                    "bit", "b", "KiB", "MiB", "GiB", "TiB", "PiB", "EiB", "ZiB", "BiB", "NiB", "DiB"]
+        self.__check__(tag)
+        
+    def __check__(self, obj):
+        if obj in self.tags: pass
+        elif obj.upper() in self.tags: pass
+        else: raise TypeError(f"unknown byte type \"{obj}\"")
+    
+    def convert(self, ByteType: str):
+        self.__check__(ByteType)
+        if self.tag.lower() == "bit" or ByteType.lower() == "bit":
+            pass
+        else:
+            index = self.tags.index(self.tag)
+            convertindex = self.tags.index(ByteType)
+            out = self.tags[index: convertindex]
+            for _ in frange(out):
+                if index > convertindex: self.length = self.length * 1024
+                else: self.length = self.length / 1024
+            self.tag = ByteType
+            
+            newObj = list()
+            
+            
+
 if _os.name == "posix":
     import re as _re
     import tty as _tty
@@ -434,7 +454,7 @@ if _os.name == "posix":
             self.sftp.close()
         
 
-    def localmode(event=lambda fd: _os.read(fd, 7).decode("utf-8")):
+    def KeyDownContinue(event=lambda fd: _os.read(fd, 7).decode("utf-8")):
         fd = _system.stdin.fileno()
         old_ttyinfo = _termios.tcgetattr(fd)
         new_ttyinfo = old_ttyinfo[:]
